"""
Bundles extended BOs
"""
from ibims.bo.bilanzierung import Bilanzierung
from ibims.bo.dokument import Dokument
from ibims.bo.file import File
from ibims.bo.geschaeftspartner import GeschaeftspartnerErweitert
from ibims.bo.hinweis import Hinweis
from ibims.bo.kampagne import Kampagne
from ibims.bo.marktlokation_erweitert import MarktlokationErweitert
from ibims.bo.rechnung import RechnungErweitert
from ibims.bo.zaehler import ZaehlerErweitert, ZaehlerGas
