"""
Bundles new enum
"""
from ibims.enum.abgabeart import Abgabeart
from ibims.enum.bdewartikelnummer import BDEWArtikelnummerErweitert
from ibims.enum.botyp import BoTypErweitert
from ibims.enum.hinweisthema import HinweisThema
from ibims.enum.messtechnische_einordnung import MesstechnischeEinordnung
from ibims.enum.messwerterfassung import Messwerterfassung
from ibims.enum.messwertstatus import Messwertstatus
from ibims.enum.rechnung_erweitert import RechnungstypErweitert
from ibims.enum.regelzone import Regelzone
from ibims.enum.zaehlertyp_erweitert import ZaehlerTypErweitert
