"""
Bundles extended and new COMs
"""
from ibims.com.adresse import AdresseErweitert
from ibims.com.bankverbindung import Bankverbindung
from ibims.com.concessionfee import ConcessionFee
from ibims.com.preisgarantie import PreisgarantieErweitert
from ibims.com.preisposition import PreispositionErweitert
from ibims.com.rechnungsposition import RechnungspositionErweitert
from ibims.com.sepa_info import SepaInfo
from ibims.com.steuerbetrag import SteuerbetragErweitert
from ibims.com.verbrauch import VerbrauchErweitert
from ibims.com.vertragskonto import Vertragskonto, VertragskontoCBA, VertragskontoMBA
from ibims.com.zaehlpunkt import Zaehlpunkt
from ibims.com.zaehlwerk import ZaehlwerkErweitert
